/**
 * @file comm.h
 * Communication interface
 * @author Marko Mkel (marko.makela@nic.funet.fi)
 */

/* Copyright  2001,2002 Marko Mkel.

   This file is part of C2N232P, a program for programming the C2N232 device
   via the RS-232 interface.

   C2N232P is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   C2N232P is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   The GNU General Public License is often shipped with GNU software, and
   is generally kept in a file called COPYING or LICENSE.  If you do not
   have a copy of the license, write to the Free Software Foundation,
   59 Temple Place, Suite 330, Boston, MA 02111 USA. */

/** Communication primitives */
struct comm
{
  /** Flag: is RESET inverted? */
  int fInvRESET:1;
  /** Flag: is SCK inverted? */
  int fInvSCK:1;
  /** Flag: is MOSI inverted? */
  int fInvMOSI:1;
  /** Flag: is MISO inverted? */
  int fInvMISO:1;
  /** Set RESET
   * @param bit	new state of RESET: zero=low, nonzero=high
   * @return	zero on success, nonzero on failure
   */
  int (*comm_reset) (int bit);
  /** Set SCK
   * @param bit	new state of SCK: zero=low, nonzero=high
   * @return	zero on success, nonzero on failure
   */
  int (*comm_sck) (int bit);

  /** Set MOSI
   * @param bit	new state of SCK: zero=low, nonzero=high
   * @return	zero on success, nonzero on failure
   */
  int (*comm_mosi) (int bit);

  /** Read MISO
   * @return	0 (MOSI=low), 1 (MOSI=high), or an error code
   */
  int (*comm_miso) (void);
};

/** An AVR device */
struct avr
{
  /** part family */
  unsigned char family;
  /** part number */
  unsigned char number;
  /** name of the device */
  const char* name;
  /** flash ROM size, bytes */
  unsigned flash_size;
  /** flash ROM page size, bytes (0=apply byte programming) */
  unsigned flash_page;
  /** EEPROM size, bytes */
  unsigned eeprom_size;
  /** flash programming delay, ms */
  unsigned flash_delay;
  /** EEPROM programming delay, ms */
  unsigned eeprom_delay;
  /** Flag: is flash byte polling available */
  int fBytePoll:1;
  /** Flag: is flash page polling available */
  int fPagePoll:1;
};
