/**
 * @file par.h
 * Parallel transfer routines
 * @author Marko Mkel (marko.makela@nic.funet.fi)
 */

/*
 * Copyright  2001,2002 Marko Mkel.
 * 
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 * 
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 * 
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef COMM_PAR
/** Open the communication channel to direct parallel connection
 * @param dev	name of the communication device
 * @param conn	array of bitmasks defining the pin assignments
 * @return	zero on success, nonzero on failure
 */
int
par_init (const char* dev,
	  const unsigned char* conn);

/** Close the communication channel to direct parallel connection */
void
par_fini (void);

/** Set RESET
 * @param bit	new state of RESET: zero=negated, nonzero=asserted
 * @return	zero on success, nonzero on failure
 */
int
par_reset (int bit);

/** Set SCK
 * @param bit	new state of SCK: zero=negated, nonzero=asserted
 * @return	zero on success, nonzero on failure
 */
int
par_sck (int bit);

/** Set MOSI
 * @param bit	new state of MOSI: zero=negated, nonzero=asserted
 * @return	zero on success, nonzero on failure
 */
int
par_mosi (int bit);

/** Read MISO
 * @return	0 (negated), 1 (asserted), or an error code
 */
int
par_miso (void);

#endif /* COMM_PAR */
