/**
 * @file serial.h
 * Serial transfer routines
 * @author Marko Mkel (marko.makela@nic.funet.fi)
 */

/*
 * Copyright  2001,2002 Marko Mkel.
 * 
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 * 
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 * 
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef COMM_SERIAL
/** Open the communication channel to direct serial connection
 * @param dev	name of the communication device
 * @param conn	dummy parameter
 * @return	zero on success, nonzero on failure
 */
int
serial_init (const char* dev,
	     const unsigned char* conn);

/** Close the communication channel to direct serial connection */
void
serial_fini (void);

/** Set DTR
 * @param bit	new state of DTR: zero=negated, nonzero=asserted
 * @return	zero on success, nonzero on failure
 */
int
serial_dtr (int bit);

/** Set RTS
 * @param bit	new state of RTS: zero=negated, nonzero=asserted
 * @return	zero on success, nonzero on failure
 */
int
serial_rts (int bit);

/** Set TXD
 * @param bit	new state of TXD: zero=negated, nonzero=asserted
 * @return	zero on success, nonzero on failure
 */
int
serial_txd (int bit);

/** Read CTS
 * @return	0 (negated), 1 (asserted), or an error code
 */
int
serial_cts (void);

#endif /* COMM_SERIAL */
